using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Parallax.Serial.IO;

namespace Parallax.Test_Input
{
	//=========================================================================
	public partial class Form1 : Form
	{
		//=========================================================================
		#region -= declarations =-

		Parallax.Serial.IO.MyRobot m_objRobot;

		#endregion
		//=========================================================================

		//=========================================================================
		#region -= constructor =-

		//=========================================================================
		public Form1()
		{
			InitializeComponent();

			//----
			this.m_objRobot = new MyRobot();
			this.m_objRobot.DataReceived += new MyRobot.RobotDataReceivedEventHandler(m_objRobot_DataReceived);
		}
		//=========================================================================

		#endregion
		//=========================================================================

		//=========================================================================
		#region -= event handlers =-
		
		//=========================================================================
		private void Form1_Load(object sender, EventArgs e)
		{
			//---- populate the serial ports
			this.PopulateSerialPortList();
			//---- set the open/close port button text to open as default.
			this.btnOpenClosePort.Text = "Open Port";
		}
		//=========================================================================

		//=========================================================================
		private void btnSendInstructions_Click(object sender, EventArgs e)
		{
			//---- set our status
			this.lblCurrentStatus.Text = "Sending Instruction to R0b0t";
			//---- set the serial port name
			this.m_objRobot.SerialPortName = this.lstComPorts.SelectedItem as string;
			//---- send the instructions
			this.m_objRobot.SendInstructions(this.txtInstructions.Text);
			//----
			this.lblCurrentStatus.Text = "Instructions Sent";
			//----
			this.btnOpenClosePort.Text = "Close Port";
		}
		//=========================================================================

		//=========================================================================
		void m_objRobot_DataReceived(object sender, System.IO.Ports.SerialDataReceivedEventArgs e)
		{
			//---- turn this off so we don't have to follow the wonky separate thread event handler model
			CheckForIllegalCrossThreadCalls = false;
			//---- update the response window
			this.txtResponse.Text += ((MyRobot)sender).Port.ReadExisting().Replace("\n", "\r\n");
		}
		//=========================================================================

		//=========================================================================
		private void btnRefreshPorts_Click(object sender, EventArgs e)
		{
			this.PopulateSerialPortList();
		}
		//=========================================================================

		//=========================================================================
		private void btnClear_Click(object sender, EventArgs e)
		{
			this.txtResponse.Clear();
		}
		//=========================================================================

		#endregion
		//=========================================================================

		//=========================================================================
		#region -= internal methods =-

		//=========================================================================
		protected override void OnClosing(CancelEventArgs e)
		{
			base.OnClosing(e);

			if (this.m_objRobot != null)
			{ this.m_objRobot.Close(); }
		}
		//=========================================================================

		//=========================================================================
		protected void PopulateSerialPortList()
		{
			//---- enumerate the ports
			string[] ports = System.IO.Ports.SerialPort.GetPortNames();
			this.lstComPorts.DataSource = ports;
		}
		//=========================================================================

		//=========================================================================
		private void btnOpenClosePort_Click(object sender, EventArgs e)
		{
			//---- set the serial port name
			this.m_objRobot.SerialPortName = this.lstComPorts.SelectedItem as string;
			//---- if the port is open, close it and update the button and status
			if (this.m_objRobot.PortIsOpen)
			{
				this.m_objRobot.Close();
				this.btnOpenClosePort.Text = "Open Port";
				this.lblCurrentStatus.Text = "Port Closed";
			}
			//---- if the port isn't open, open it and update the interface
			else
			{
				this.m_objRobot.Open();
				this.btnOpenClosePort.Text = "Close Port";
				this.lblCurrentStatus.Text = "Port Opened";
			}
		}
		//=========================================================================

		#endregion
		//=========================================================================
	}
	//=========================================================================
}